@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2022-01-04 16:38:59
+@LastEditTime: 2022-02-10 14:34:02
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,6 +11,7 @@ from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.act_base_model import *
 from seven_cloudapp_frame.models.cms_base_model import *
 from seven_cloudapp_frame.models.prize_base_model import *
+from seven_cloudapp_frame.models.price_base_model import *
 
 
 class ActInfoHandler(ClientBaseHandler):
@@ -113,3 +114,25 @@ class CmsInfoListHandler(ClientBaseHandler):
         page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True), ref_params={})
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
         return self.response_json_success(page_info)
+
+
+class PriceGearListHandler(ClientBaseHandler):
+    """
+    :description: 获取价格档位列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 获取价格档位列表
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: list
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 20))
+        return self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index))
