@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-04-28 14:05:09
+@LastEditTime: 2022-05-31 18:02:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -171,13 +171,19 @@ class GetCrmIntegralHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        user_nick = self.get_param("user_nick")
+        mix_nick = self.get_param("mix_nick")
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
             return self.response_json_error("error", "小程序不存在")
+        access_token = app_info_dict["access_token"]
+        if access_token == "":
+            return self.response_json_error("error", "未授权请联系客服授权")
         top_base_model = TopBaseModel(context=self)
-        invoke_result_data = top_base_model.get_crm_point_available(user_nick, app_info_dict["access_token"])
+        app_key, app_secret = self.get_app_key_secret()
+        invoke_result_data = top_base_model.get_crm_point_available(mix_nick, access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             return self.reponse_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         shop_member_integral = invoke_result_data.data
