@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-03-10 14:29:36
+@LastEditTime: 2022-04-27 13:42:04
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -142,7 +142,7 @@ class SevenHelper:
     @classmethod
     def auto_mapper(self, s_model, map_dict=None):
         '''
-        :description: 对象映射（把map_dict值赋值到实体s_model中）
+        :description: 对象映射,字典转实体（把map_dict值赋值到实体s_model中）
         :param s_model：需要映射的实体对象
         :param map_dict：被映射的实体字典
         :return: obj
@@ -450,7 +450,7 @@ class SevenHelper:
         :last_editors: HuangJianYi
         """
         sub_table = None
-        if not sub_count:
+        if not sub_count or not object_id:
             return sub_table
         sub_table = str(object_id % sub_count)
         return sub_table
