@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-03-04 15:33:47
+@LastEditTime: 2022-05-12 16:13:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -80,12 +80,13 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def get_access_token(self, grant_type="client_credential",app_id="", app_secret=""):
+    def get_access_token(self, grant_type="client_credential",app_id="", app_secret="",is_del=False):
         """
         :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
         :param grant_type: 获取access_token 时值为 client_credential
         :param app_id:app_id
         :param app_secret:app_secret
+        :param is_del:是否删除redis里的access_token
         :return: 
         :last_editors: HuangJianYi
         """
@@ -101,6 +102,8 @@ class WeChatHelper:
         response = None
         redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
         redis_key = f"wechat_access_token:{str(app_id)}"
+        if is_del == True:
+            redis_init.delete(redis_key)
         try:
             access_token = redis_init.get(redis_key)
             if access_token:
@@ -141,7 +144,15 @@ class WeChatHelper:
         """
         app_id = app_id if app_id else config.get_value("app_id")
         app_secret = app_secret if app_secret else config.get_value("app_secret")
-        invoke_result_data = self.get_access_token(app_id,app_secret)
+        invoke_result_data = InvokeResultData()
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = self.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
         if invoke_result_data.success == False:
             return invoke_result_data
         try:
@@ -170,7 +181,7 @@ class WeChatHelper:
         return invoke_result_data
 
     @classmethod
-    def get_user_phonenumber(self, code ,app_id="", app_secret=""):
+    def get_user_phonenumber(self, code, app_id="", app_secret=""):
         """
         :description:code换取用户手机号。 每个code只能使用一次，code的有效期为5min
         :param code: 手机号获取凭证
@@ -179,12 +190,20 @@ class WeChatHelper:
         :return: 
         :last_editors: HuangJianYi
         """
+        invoke_result_data = InvokeResultData()
         if not code:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "code无效，请升级微信版本到8.0.16以上"
             return invoke_result_data
-        invoke_result_data = self.get_access_token(app_id=app_id, app_secret=app_secret)
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = self.get_access_token(app_id, app_secret, True)
+                
+            if invoke_result_data.success == True:
+                break
         if invoke_result_data.success == False:
             return invoke_result_data
         access_token = invoke_result_data.data
@@ -207,6 +226,60 @@ class WeChatHelper:
             invoke_result_data.error_message = "授权手机号失败"
             return invoke_result_data
 
+    @classmethod
+    def create_qr_code(self, page, scene="a=1", width=430, app_id="", app_secret=""):
+        """
+        :description:获取小程序/小游戏的二维码
+        :param page: 页面 page，例如 pages/index/index，根路径前不要填加 /，不能携带参数（参数请放在scene字段里），如果不填写这个字段，默认跳主页面
+        :param scene: 最大32个可见字符，只支持数字，大小写英文以及部分特殊字符：!#$&'()*+,/:;=?@-._~，其它字符请自行编码为合法字符（因不支持%，中文无法使用 urlencode 处理，请使用其他编码方式）
+        :param width: 二维码的宽度，单位 px，最小 280px，最大 1280px
+        :return: 图片二进制 数据类型Array<byte>
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "wechat_qr_code:" + CryptoHelper.md5_encrypt(f"{page}_{scene}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = self.get_access_token(app_id, app_secret, True)
+                
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
+        param = {"scene": scene, "page": page, "width": width, "auto_color": True, "is_hyaline": False}
+        response = ""
+        try:
+            requset_url = 'https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=' + access_token
+            headers = {"Content-type": "application/json"}
+            response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+            try:
+                response_data = SevenHelper.json_loads(response.text)
+                if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = response_data["errcode"]
+                    invoke_result_data.error_message = response_data["errmsg"]
+                    return invoke_result_data
+            except:
+                pass
+            invoke_result_data.data = response.content
+            redis_init.set(redis_key, response.content, 3600)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【create_qr_code】" + traceback.format_exc() + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
     @classmethod
     def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv, app_id="", app_secret=""):
         """
