@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-04-26 18:58:00
+@LastEditTime: 2022-05-24 10:43:51
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -114,8 +114,10 @@ class CacheModel(BaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        if not value:
-            return
+        is_cache_empty = config.get_value("is_cache_empty",False)
+        if is_cache_empty == False:
+            if not value:
+                return
         redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
