@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-01-05 17:32:29
-@LastEditTime: 2022-01-13 14:57:05
+@LastEditTime: 2022-02-24 16:18:13
 @LastEditors: HuangJianYi
 @Description: 消息推送业务模型
 """
@@ -32,7 +32,7 @@ class PushBaseModel():
         redis_init = SevenHelper.redis_init()
         redis_key = f"wechat_subscribe_list:{app_id}"
         redis_init.zincrby(redis_key, value=open_id, amount=1)
-        redis_init.expire(redis_key,3600*24*30)
+        redis_init.expire(redis_key, 3600 * 24 * 30)
         return invoke_result_data
 
     def push_wechat_message(self, open_id, template_id, page, request_data, miniprogram_state="formal", lang="zh_CN", app_id="", app_secret="", plan_id=0):
@@ -64,25 +64,26 @@ class PushBaseModel():
             push_log_dict["app_secret"] = app_secret
             push_log_dict["plan_id"] = plan_id
             subscribe_redis_key = f"wechat_subscribe_list:{app_id}"
-            if not redis_init.zscore(subscribe_redis_key):
+            if not redis_init.zscore(subscribe_redis_key, open_id):
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "订阅次数不足"
             else:
                 redis_init.zincrby(subscribe_redis_key, value=open_id, amount=-1)
-                invoke_result_data = WeChatHelper.send_template_message(open_id, template_id, page, request_data, app_id=app_id, app_secret=app_secret)
+                invoke_result_data = WeChatHelper.send_template_message(open_id=open_id, template_id=template_id, page=page, request_data=request_data, miniprogram_state=miniprogram_state, lang=lang, app_id=app_id, app_secret=app_secret)
             push_log_dict["result"] = invoke_result_data
-            push_redis_key = f"wechat_push_list:{app_id}"
+            push_redis_key = f"wechat_pushlog_list:{app_id}"
             if plan_id > 0:
                 push_redis_key += f"_{plan_id}"
             redis_init.rpush(push_redis_key, SevenHelper.json_dumps(push_log_dict))
             redis_init.expire(push_redis_key, 3600 * 24 * 30)
             return invoke_result_data
         except Exception as ex:
+            log_info = "【推送微信订阅信息】" + traceback.format_exc()
             if self.context:
-                self.context.logging_link_error("【推送微信订阅信息】" + traceback.format_exc())
+                self.context.logging_link_error(log_info)
             elif self.logging_link_error:
-                self.logging_link_error("【推送微信订阅信息】" + traceback.format_exc())
+                self.logging_link_error(log_info)
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
