@@ -46,14 +46,17 @@ class StatBaseModel(FrameBaseModel):
         stat_queue.key_value = key_value
         stat_queue.create_date = SevenHelper.get_now_datetime()
         stat_queue.process_date = SevenHelper.get_now_datetime()
-
+        
+        redis_init = SevenHelper.redis_init()
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
-            sub_table_config = config.get_value("sub_table_config", {})
-            stat_queue_model = StatQueueModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("stat_queue_num", 0)), context=self.context)
-            stat_queue_model.add_entity(stat_queue)
+            stat_queue_model = StatQueueModel(context=self.context)
+            id = stat_queue_model.add_entity(stat_queue)
+            stat_queue_id = redis_init.get("log_stat_queue:id")
+            if stat_queue_id and id < int(stat_queue_id):
+                redis_init.set("log_stat_queue:info",SevenHelper.json_dumps({"stat_queue_id":stat_queue_id,"id":id,"create_date":TimeHelper.get_now_format_time()}),30*24*3600)
+            redis_init.set("log_stat_queue:id",id,3600)
         else:
-            redis_init = SevenHelper.redis_init()
             redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
     def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, key_list_dict):
@@ -84,8 +87,7 @@ class StatBaseModel(FrameBaseModel):
 
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
-            sub_table_config = config.get_value("sub_table_config", {})
-            stat_queue_model = StatQueueModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("stat_queue_num", 0)), context=self.context)
+            stat_queue_model = StatQueueModel(context=self.context)
             return stat_queue_model.add_list(stat_queue_list)
         else:
             redis_init = SevenHelper.redis_init()
